==> haskell-weigh-0.0.17-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.17
visibility:           public
id:                   weigh-0.0.17-G5fYhPFjZImIh987aGsjXB
key:                  weigh-0.0.17-G5fYhPFjZImIh987aGsjXB
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  70a2e00442ff33fb93c2197ad9100b7f
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
library-dirs:         /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.17-G5fYhPFjZImIh987aGsjXB
depends:
    base-4.16.4.0 criterion-measurement-0.2.1.0-65ouDijD4ThHWypo06hLoh
    deepseq-1.4.6.1 ghc-9.2.8 mtl-2.2.2 process-1.6.16.0
    split-0.2.5-FikGR5xLeivE3fJUC4tXgQ
    temporary-1.3-ATBZpgmb4kkJvnIbOIhyK2

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-weigh-0.0.17-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-weigh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 weigh
version:              0.0.17
visibility:           public
id:                   weigh-0.0.17-DOHmIpasTdWLPp0kVFdwI6
key:                  weigh-0.0.17-DOHmIpasTdWLPp0kVFdwI6
license:              BSD-3-Clause
copyright:            FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
homepage:             https://github.com/fpco/weigh#readme
synopsis:             Measure allocations of a Haskell functions/values
description:          Please see README.md
category:             Web
abi:                  587408096b3a3dfa6cc8a8daabbb93aa
exposed:              True
exposed-modules:      Weigh
hidden-modules:       Weigh.GHCStats
import-dirs:          /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
library-dirs:         /usr/lib/ghc-9.2.8/site-local/weigh-0.0.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-weigh
hs-libraries:         HSweigh-0.0.17-DOHmIpasTdWLPp0kVFdwI6
depends:
    base-4.16.4.0 criterion-measurement-0.2.2.0-3NmiEWEqD6U5bykgzIrOdI
    deepseq-1.4.6.1 ghc-9.2.8 mtl-2.2.2 process-1.6.16.0
    split-0.2.5-Gzu4NbNnTUj6rs5DfMztSh
    temporary-1.3-FDskYhMei4uKi1JCFLXz31

haddock-interfaces:   /usr/share/doc/haskell-weigh/html/weigh.haddock
haddock-html:         /usr/share/doc/haskell-weigh/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
